@@ -219,6 +219,19 @@ class Client(ABC):
             for field in obj_xml['Fields'][0]['Field']:
                 result[field.attributes['internal_name']] = field.text
 
+            table_fields = obj_xml.find('TableFields')
+            if table_fields:
+                for table_field in table_fields['TableField']:
+                    table_field_result = []
+                    cols = [ col.attributes['internal_name'] for col in table_field['Columns'][0]['Column'] ]
+                    for row in table_field.findall('Row'):
+                        row_result = {}
+                        for i, col in enumerate(cols):
+                            row_result[col] = row.subelements[i].text
+                        table_field_result.append(row_result)
+
+                    result[table_field.attributes['internal_name']] = table_field_result
+
             return result
 
     def execute_sql(self, sql_command:str) -> Union[List[Dict[str, str]], None]:
