@@ -333,7 +333,7 @@ class JobCaller:
 
             infered_value = None
             if param_type == ParamTypes.STRING.value:
-                infered_value = str(value, 'ascii')
+                infered_value = str(value, 'UTF-8')
             elif param_type == ParamTypes.INTEGER.value:
                 infered_value = int(value)
             elif param_type == ParamTypes.BOOLEAN.value:
